#ifndef MARS_MSimCamera
#define MARS_MSimCamera

#ifndef MARS_MTask
#include "MTask.h"
#endif

class MMcEvt;
class MParList;
class MPhotonEvent;
class MPhotonStatistics;
class MRawRunHeader;
class MAnalogChannels;
class MPedestalCam;

class MSpline3;

class MSimCamera : public MTask
{
private:
    MPhotonEvent      *fEvt;             //! Event stroing the photons
    MPhotonStatistics *fStat;            //! Valid time range of the phootn event
    MRawRunHeader     *fRunHeader;       //! Sampling frequency
    MPedestalCam      *fElectronicNoise; //! Electronic noise (baseline and rms)
    MPedestalCam      *fGain;            //! Electronic noise (baseline and rms)

    MAnalogChannels   *fCamera;          //! Output of the analog signals
    MMcEvt            *fMcEvt;           //! For information stored in MMcEvt

    MSpline3 *fSpline;     // Pusle Shape

    Bool_t fBaselineGain;  // Should the gain be applied to baseline and electronic noise?

    // MParContainer
    Int_t ReadEnv(const TEnv &env, TString prefix, Bool_t print);

    // MTask
    Int_t  PreProcess(MParList *pList);
    Bool_t ReInit(MParList *pList);
    Int_t  Process();

public:
    MSimCamera(const char *name=NULL, const char *title=NULL);

    ClassDef(MSimCamera, 0) // Task to simulate the electronic noise and to convert photons into pulses
};

#endif
